@@ -17,8 +17,9 @@
 #include "konqapplication.h"
 
 #include "konqdebug.h"
-#include <kwindowsystem.h>
 #include <KStartupInfo>
+#include <KWindowInfo>
+#include <kwindowsystem.h>
 
 #include <QFile>
 
@@ -29,8 +30,12 @@
 #endif
 
 #ifdef KActivities_FOUND
+#if QT_VERSION_MAJOR < 6
 #include <KActivities/Consumer>
-#endif
+#else //QT_VERSION_MAJOR
+#include <PlasmaActivities/Consumer>
+#endif //QT_VERSION_MAJOR
+#endif //KActivities_FOUND
 
 // these DBus calls come from outside, so any windows created by these
 // calls would have old user timestamps (for KWin's no-focus-stealing),
@@ -103,7 +108,7 @@ QList<QDBusObjectPath> KonquerorAdaptor::getWindows()
     QList<QDBusObjectPath> lst;
     QList<KonqMainWindow *> *mainWindows = KonqMainWindow::mainWindowList();
     if (mainWindows) {
-        foreach (KonqMainWindow *window, *mainWindows) {
+        for (KonqMainWindow *window: *mainWindows) {
             lst.append(QDBusObjectPath(window->dbusName()));
         }
     }
