@@ -18,6 +18,10 @@
 #include "konqpixmapprovider.h"
 #include "implementations/konqbrowserwindowinterface.h"
 #include "interfaces/downloaderextension.h"
+#include "browserarguments.h"
+#include "browserextension.h"
+#include "placeholderpart.h"
+#include "konqurl.h"
 
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
@@ -31,30 +35,67 @@
 
 #include <QApplication>
 #include <QArgument>
-#include <QByteRef>
 #include <QFile>
 #include <QDropEvent>
 #include <QDBusConnection>
 #include <QMimeData>
 
+#include <config-konqueror.h>
+
 #ifdef KActivities_FOUND
+#if QT_VERSION_MAJOR < 6
 #include <KActivities/ResourceInstance>
-#endif
+#else //QT_VERSION_MAJOR
+#include <PlasmaActivities/ResourceInstance>
+#endif //QT_VERSION_MAJOR
+#endif //KActivities_FOUND
+
 #include <kparts_version.h>
 
 #include <KJobWidgets>
 #include <KParts/Part>
 #include <KParts/StatusBarExtension>
 #include <KParts/ReadOnlyPart>
-#include <KParts/BrowserArguments>
 #include <KParts/OpenUrlEvent>
 #include <KParts/OpenUrlArguments>
-#include <KParts/BrowserExtension>
-#include <KParts/WindowArgs>
 #include <QMimeDatabase>
 
 //#define DEBUG_HISTORY
 
+KonqView::KonqView(KonqFrame *viewFrame, KonqMainWindow *mainWindow) :
+    m_pPart{nullptr},
+    m_pageSecurity{KonqMainWindow::NotCrypted},
+    m_lstHistoryIndex{-1},
+    m_doPost{false},
+    m_pMainWindow{mainWindow},
+    m_loader{nullptr},
+    m_pKonqFrame{viewFrame},
+    m_bLoading{false},
+    m_bLockedLocation{false},
+    m_bPassiveMode{false},
+    m_bLinkedView{false},
+    m_bToggleView{false},
+    m_bLockHistory{false},
+    m_bAborted{false},
+    m_bGotIconURL{false},
+    m_bPopupMenuEnabled{true},
+    m_bFollowActive{false},
+    m_bPendingRedirection{false},
+    m_bBuiltinView{true},
+    m_bURLDropHandling{false},
+    m_bDisableScrolling{false},
+    m_bErrorURL{false}
+#if QT_VERSION_MAJOR < 6
+#ifdef KActivities_FOUND
+    , m_activityResourceInstance{new KActivities::ResourceInstance(mainWindow->winId(), this)}
+#endif
+#endif
+{
+    m_pKonqFrame->setView(this);
+    KonqViewFactory factory;
+    switchView(factory, true);
+}
+
 KonqView::KonqView(KonqViewFactory &viewFactory,
                    KonqFrame *viewFrame,
                    KonqMainWindow *mainWindow,
@@ -97,8 +138,10 @@ KonqView::KonqView(KonqViewFactory &viewFactory,
     m_bURLDropHandling = false;
     m_bErrorURL = false;
 
+#if QT_VERSION_MAJOR < 6
 #ifdef KActivities_FOUND
     m_activityResourceInstance = new KActivities::ResourceInstance(mainWindow->winId(), this);
+#endif
 #endif
 
     switchView(viewFactory);
@@ -146,10 +189,10 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
         args = m_pPart->arguments();
     }
 
-    KParts::BrowserExtension *ext = browserExtension();
-    KParts::BrowserArguments browserArgs;
-    if (ext) {
-        browserArgs = ext->browserArguments();
+    KParts::NavigationExtension *ext = browserExtension();
+    BrowserArguments browserArgs;
+    if (BrowserExtension *browserExtension = qobject_cast<BrowserExtension *>(ext)) {
+        browserArgs = browserExtension->browserArguments();
     }
 
     // Typing "Enter" again after the URL of an aborted view, triggers a reload.
@@ -228,11 +271,15 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
 #endif
 
 #ifdef KActivities_FOUND
+#if QT_VERSION_MAJOR < 6
     m_activityResourceInstance->setUri(url);
 
     if (m_pPart->widget()->hasFocus()) {
         m_activityResourceInstance->notifyFocusedIn();
     }
+#else
+    KActivities::ResourceInstance::notifyAccessed(url);
+#endif
 #endif
 }
 
@@ -254,11 +301,11 @@ void KonqView::switchEmbeddingPart(const QString& newPluginId, const QString& ne
     }
 }
 
-void KonqView::switchView(KonqViewFactory &viewFactory)
+void KonqView::switchView(KonqViewFactory &viewFactory, bool allowPlaceholder)
 {
     //qCDebug(KONQUEROR_LOG);
     KParts::ReadOnlyPart *oldPart = m_pPart;
-    KParts::ReadOnlyPart *part = m_pKonqFrame->attach(viewFactory);   // creates the part
+    KParts::ReadOnlyPart *part = m_pKonqFrame->attach(viewFactory, allowPlaceholder);   // creates the part
     if (!part) {
         return;
     }
@@ -392,7 +439,7 @@ void KonqView::connectPart()
     if (m_pPart) {
         KonqInterfaces::DownloaderExtension *dext = KonqInterfaces::DownloaderExtension::downloader(m_pPart);
         if (dext) {
-            connect(dext, &KonqInterfaces::DownloaderExtension::downloadAndOpenUrl, m_pMainWindow, [dext, this](const QUrl &url, int id, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs, bool temp){
+            connect(dext, &KonqInterfaces::DownloaderExtension::downloadAndOpenUrl, m_pMainWindow, [dext, this](const QUrl &url, int id, const KParts::OpenUrlArguments &args, const BrowserArguments &bargs, bool temp){
                     KonqOpenURLRequest req(args, bargs, dext->part(), true, id);
                     req.tempFile = temp;
                     m_pMainWindow->slotOpenURLRequest(url, req);
@@ -400,18 +447,36 @@ void KonqView::connectPart()
         }
     }
 
-    KParts::BrowserExtension *ext = browserExtension();
-
+    KParts::NavigationExtension *ext = browserExtension();
     if (ext) {
-        
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         KonqBrowserWindowInterface *bi = new KonqBrowserWindowInterface(mainWindow(), m_pPart);
         ext->setBrowserInterface(bi);
-        
-        connect(ext, &KParts::BrowserExtension::openUrlRequestDelayed, ext,
+
+        connect(ext, &KParts::NavigationExtension::openUrlRequestDelayed, ext,
                 [ext, this](const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs){
                     KonqOpenURLRequest req(args, bargs, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
                     m_pMainWindow->slotOpenURLRequest(url, req);
                 });
+#else
+        
+        if (auto browserExtension = qobject_cast<BrowserExtension *>(ext)) {
+            connect(browserExtension, &BrowserExtension::browserOpenUrlRequestDelayed, m_pMainWindow, [ext, this](const QUrl &url, const KParts::OpenUrlArguments &arguments, const BrowserArguments &browserArguments){
+                KonqOpenURLRequest req(arguments, browserArguments, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                    m_pMainWindow->slotOpenURLRequest(url, req);
+            });
+            KonqBrowserWindowInterface *bi = new KonqBrowserWindowInterface(mainWindow(), m_pPart);
+            browserExtension->setBrowserInterface(bi);
+        } else {
+            connect(ext, &BrowserExtension::openUrlRequestDelayed, m_pMainWindow,
+                [ext, this](const QUrl &url, const KParts::OpenUrlArguments &args){
+                    KonqOpenURLRequest req(args, {}, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                    m_pMainWindow->slotOpenURLRequest(url, req);
+                });
+        }
+#endif
+
 
         if (m_bPopupMenuEnabled) {
             m_bPopupMenuEnabled = false; // force
@@ -427,11 +492,27 @@ void KonqView::connectPart()
         connect(ext, SIGNAL(setPageSecurity(int)),
                 this, SLOT(setPageSecurity(int)));
 
-        connect(ext, &KParts::BrowserExtension::createNewWindow, ext,
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        connect(ext, &KParts::NavigationExtension::createNewWindow, ext,
                 [ext, this] (const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs, const KParts::WindowArgs &wargs ,KParts::ReadOnlyPart** part) {
                     KonqOpenURLRequest req(args, bargs, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
                     m_pMainWindow->slotCreateNewWindow(url, req, wargs, part);
                 });
+#else
+        if (auto browserExtension = qobject_cast<BrowserExtension *>(ext)) {
+            connect(browserExtension, &BrowserExtension::browserCreateNewWindow, ext,
+                    [ext, this] (const QUrl &url, const KParts::OpenUrlArguments &args, const BrowserArguments &bargs, const WindowArgs &wargs ,KParts::ReadOnlyPart** part) {
+                        KonqOpenURLRequest req(args, bargs, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                        m_pMainWindow->slotCreateNewWindow(url, req, wargs, part);
+                    });
+        } else {
+            connect(ext, &KParts::NavigationExtension::createNewWindow, ext,
+                    [ext, this] (const QUrl &url) {
+                        KonqOpenURLRequest req({}, {}, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                        m_pMainWindow->slotCreateNewWindow(url, req);
+                    });
+        }
+#endif
 
         connect(ext, SIGNAL(loadingProgress(int)),
                 m_pKonqFrame->statusbar(), SLOT(slotLoadingProgress(int)));
@@ -464,7 +545,7 @@ void KonqView::connectPart()
                 this, SLOT(slotRequestFocus(KParts::ReadOnlyPart*)));
 
         if (service().pluginId() != QLatin1String("konq_sidebartng")) {
-            connect(ext, &KParts::BrowserExtension::infoMessage, m_pKonqFrame->statusbar(), &KonqFrameStatusBar::message);
+            connect(ext, &KParts::NavigationExtension::infoMessage, m_pKonqFrame->statusbar(), &KonqFrameStatusBar::message);
 
             //Must use this form of connect because slotAddWebSideBar is private
             connect(ext, SIGNAL(addWebSideBar(QUrl,QString)), m_pMainWindow, SLOT(slotAddWebSideBar(QUrl,QString)));
@@ -898,7 +979,7 @@ void KonqView::copyHistory(KonqView *other)
     qDeleteAll(m_lstHistory);
     m_lstHistory.clear();
 
-    foreach (HistoryEntry *he, other->m_lstHistory) {
+    for (HistoryEntry *he: other->m_lstHistory) {
         appendHistoryEntry(new HistoryEntry(*he));
     }
     setHistoryIndex(other->historyIndex());
@@ -1035,7 +1116,7 @@ void KonqView::setPartMimeType()
 
 bool KonqView::callExtensionMethod(const char *methodName)
 {
-    QObject *obj = KParts::BrowserExtension::childObject(m_pPart);
+    QObject *obj = KParts::NavigationExtension::childObject(m_pPart);
     if (!obj) { // not all views have a browser extension !
         return false;
     }
@@ -1045,7 +1126,7 @@ bool KonqView::callExtensionMethod(const char *methodName)
 
 bool KonqView::callExtensionBoolMethod(const char *methodName, bool value)
 {
-    QObject *obj = KParts::BrowserExtension::childObject(m_pPart);
+    QObject *obj = KParts::NavigationExtension::childObject(m_pPart);
     if (!obj) { // not all views have a browser extension !
         return false;
     }
@@ -1055,7 +1136,7 @@ bool KonqView::callExtensionBoolMethod(const char *methodName, bool value)
 
 bool KonqView::callExtensionURLMethod(const char *methodName, const QUrl &value)
 {
-    QObject *obj = KParts::BrowserExtension::childObject(m_pPart);
+    QObject *obj = KParts::NavigationExtension::childObject(m_pPart);
     if (!obj) { // not all views have a browser extension !
         return false;
     }
@@ -1080,7 +1161,7 @@ void KonqView::enablePopupMenu(bool b)
 {
     Q_ASSERT(m_pMainWindow);
 
-    KParts::BrowserExtension *ext = browserExtension();
+    KParts::NavigationExtension *ext = browserExtension();
 
     if (!ext) {
         return;
@@ -1090,24 +1171,79 @@ void KonqView::enablePopupMenu(bool b)
         return;
     }
 
-    // enable context popup
-    if (b) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    //Store signal and slot overloads in variable so that they can be reused in both branches
+    using namespace KParts;
+    auto sigOverloadFileItem = QOverload<const QPoint&, const KFileItemList&, const OpenUrlArguments &, const BrowserArguments&,
+        NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&NavigationExtension::popupMenu);
+    auto slotOverloadFileItem = QOverload<const QPoint&, const KFileItemList&, const OpenUrlArguments &, const BrowserArguments&,
+        NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&KonqMainWindow::slotPopupMenu);
+    auto sigOverloadUrl = QOverload<const QPoint&, const QUrl&, mode_t, const OpenUrlArguments& , const BrowserArguments& ,
+        NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&NavigationExtension::popupMenu);
+    auto slotOverloadUrl = QOverload<const QPoint&, const QUrl&, mode_t, const OpenUrlArguments& , const BrowserArguments& ,
+        NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&KonqMainWindow::slotPopupMenu);
+    if (b) { // enable context popup
         m_bPopupMenuEnabled = true;
-
-        connect(ext, SIGNAL(popupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
-                m_pMainWindow, SLOT(slotPopupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)));
-
-        connect(ext, SIGNAL(popupMenu(QPoint,QUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
-                m_pMainWindow, SLOT(slotPopupMenu(QPoint,QUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)));
+        connect(ext,sigOverloadFileItem, m_pMainWindow, slotOverloadFileItem);
+        connect(ext, sigOverloadUrl, m_pMainWindow, slotOverloadUrl);
     } else { // disable context popup
         m_bPopupMenuEnabled = false;
-
-        disconnect(ext, SIGNAL(popupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
-                   m_pMainWindow, SLOT(slotPopupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)));
-
-        disconnect(ext, SIGNAL(popupMenu(QPoint,QUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
-                   m_pMainWindow, SLOT(slotPopupMenu(QPoint,QUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)));
+        disconnect(ext,sigOverloadFileItem, m_pMainWindow, slotOverloadFileItem);
+        disconnect(ext, sigOverloadUrl, m_pMainWindow, slotOverloadUrl);
     }
+#else
+    if (auto browserExtension = qobject_cast<BrowserExtension *>(ext)) {
+        using namespace KParts;
+        auto slotOverloadFileItem = QOverload<const QPoint&, const KFileItemList&, const OpenUrlArguments &, const BrowserArguments&,
+                NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&KonqMainWindow::slotPopupMenu);
+        auto slotOverloadUrl = QOverload<const QPoint&, const QUrl&, mode_t, const OpenUrlArguments& , const BrowserArguments& ,
+                NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&KonqMainWindow::slotPopupMenu);
+
+        if (b) {
+            m_bPopupMenuEnabled = true;
+            connect(browserExtension, &BrowserExtension::browserPopupMenuFromFiles, m_pMainWindow, slotOverloadFileItem);
+            connect(browserExtension, &BrowserExtension::browserPopupMenuFromUrl, m_pMainWindow, slotOverloadUrl);
+        } else {
+             m_bPopupMenuEnabled = false;
+            disconnect(browserExtension, &BrowserExtension::browserPopupMenuFromFiles, m_pMainWindow, slotOverloadFileItem);
+            disconnect(browserExtension, &BrowserExtension::browserPopupMenuFromUrl, m_pMainWindow, slotOverloadUrl);
+        }
+    } else {
+        //Store signal and slot overloads in variable so that they can be reused in both branches
+        using namespace KParts;
+        auto sigOverloadFileItem = QOverload<const QPoint&, const KFileItemList&, const OpenUrlArguments &,            NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&NavigationExtension::popupMenu);
+        auto sigOverloadUrl = QOverload<const QPoint&, const QUrl&, mode_t, const OpenUrlArguments& ,
+            NavigationExtension::PopupFlags, const NavigationExtension::ActionGroupMap&>::of(&NavigationExtension::popupMenu);
+        if (b) { // enable context popup
+            m_bPopupMenuEnabled = true;
+            connect(ext,sigOverloadFileItem, this, &KonqView::slotPopupMenuFiles);
+            connect(ext, sigOverloadUrl, this, &KonqView::slotPopupMenuUrl);
+        } else { // disable context popup
+            m_bPopupMenuEnabled = false;
+            disconnect(ext,sigOverloadFileItem, this, &KonqView::slotPopupMenuFiles);
+            disconnect(ext, sigOverloadUrl, this, &KonqView::slotPopupMenuUrl);
+        }
+    }
+#endif
+}
+
+void KonqView::slotPopupMenuFiles(const QPoint &global,
+            const KFileItemList &items,
+            const KParts::OpenUrlArguments &args,
+            KParts::NavigationExtension::PopupFlags flags,
+            const KParts::NavigationExtension::ActionGroupMap &actionGroups)
+{
+    m_pMainWindow->slotPopupMenu(global, items, args, {}, flags, actionGroups);
+}
+
+void KonqView::slotPopupMenuUrl(const QPoint &global,
+                   const QUrl &url,
+                   mode_t mode,
+                   const KParts::OpenUrlArguments &arguments,
+                   KParts::NavigationExtension::PopupFlags flags,
+                   const KParts::NavigationExtension::ActionGroupMap &actionGroups)
+{
+    m_pMainWindow->slotPopupMenu(global, url, mode, arguments, {}, flags, actionGroups);
 }
 
 void KonqView::reparseConfiguration()
@@ -1171,12 +1307,13 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
         const QMimeData *mimeData = ev->mimeData();
 
         QList<QUrl> lstDragURLs = KUrlMimeData::urlsFromMimeData(mimeData);
-        KParts::BrowserExtension *ext = browserExtension();
+        KParts::NavigationExtension *ext = browserExtension();
         if (!lstDragURLs.isEmpty() && ext && lstDragURLs.first().isValid()) {
             emit ext->openUrlRequest(lstDragURLs.first());    // this will call m_pMainWindow::slotOpenURLRequest delayed
         }
     }
 
+#if QT_VERSION_MAJOR < 6
 #ifdef KActivities_FOUND
     if (e->type() == QEvent::FocusIn) {
         m_activityResourceInstance->notifyFocusedIn();
@@ -1185,12 +1322,13 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
     if (e->type() == QEvent::FocusOut) {
         m_activityResourceInstance->notifyFocusedOut();
     }
+#endif
 #endif
 
     return false;
 }
 
-bool KonqView::prepareReload(KParts::OpenUrlArguments &args, KParts::BrowserArguments &browserArgs, bool softReload)
+bool KonqView::prepareReload(KParts::OpenUrlArguments &args, BrowserArguments &browserArgs, bool softReload)
 {
     args.setReload(true);
     if (softReload) {
@@ -1216,9 +1354,9 @@ bool KonqView::prepareReload(KParts::OpenUrlArguments &args, KParts::BrowserArgu
     return true;
 }
 
-KParts::BrowserExtension *KonqView::browserExtension() const
+KParts::NavigationExtension *KonqView::browserExtension() const
 {
-    return m_pPart ? KParts::BrowserExtension::childObject(m_pPart) : nullptr;
+    return m_pPart ? KParts::NavigationExtension::childObject(m_pPart) : nullptr;
 }
 
 KParts::StatusBarExtension *KonqView::statusBarExtension() const
@@ -1277,6 +1415,30 @@ void HistoryEntry::saveConfig(KConfigGroup &config, const QString &prefix, const
     }
 }
 
+HistoryEntry* HistoryEntry::fromDelayedLoadingData(const KConfigGroup& config, const QString& prefix, const KonqFrameBase::Options& options)
+{
+    HistoryEntry *entry = new HistoryEntry;
+    if (options & (KonqFrameBase::SaveUrls|KonqFrameBase::SaveHistoryItems)) { // eitentryr one
+        entry->url = QUrl(config.readEntry(QStringLiteral("Url").prepend(prefix), ""));
+        entry->locationBarURL = config.readEntry(QStringLiteral("LocationBarURL").prepend(prefix), "");
+        entry->title = config.readEntry(QStringLiteral("Title").prepend(prefix), "");
+        entry->strServiceType = config.readEntry(QStringLiteral("StrServiceType").prepend(prefix), "");
+        entry->strServiceName = config.readEntry(QStringLiteral("StrServiceName").prepend(prefix), "");
+    }
+    if (options & KonqFrameBase::SaveUrls) {
+        entry->reload = true;
+    } else if (options & KonqFrameBase::SaveHistoryItems) {
+        entry->buffer = config.readEntry(QStringLiteral("Buffer").prepend(prefix), QByteArray());
+        entry->postData = config.readEntry(QStringLiteral("PostData").prepend(prefix), QByteArray());
+        entry->postContentType = config.readEntry(QStringLiteral("PostContentType").prepend(prefix), "");
+        entry->doPost = config.readEntry(QStringLiteral("DoPost").prepend(prefix), false);
+        entry->pageReferrer = config.readEntry(QStringLiteral("PageReferrer").prepend(prefix), "");
+        entry->pageSecurity = static_cast<KonqMainWindow::PageSecurity>(config.readEntry(QStringLiteral("PageSecurity").prepend(prefix), 0));
+        entry->reload = false;
+    }
+    return entry;
+}
+
 void HistoryEntry::loadItem(const KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
 {
     if (options & (KonqFrameBase::SaveUrls|KonqFrameBase::SaveHistoryItems)) { // either one
@@ -1300,14 +1462,28 @@ void HistoryEntry::loadItem(const KConfigGroup &config, const QString &prefix, c
     }
 }
 
+Konq::PlaceholderPart* KonqView::placeholderPart() const
+{
+    return qobject_cast<Konq::PlaceholderPart*>(m_pPart);
+}
+
 void KonqView::saveConfig(KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
 {
-    config.writeEntry(QStringLiteral("ServiceType").prepend(prefix), serviceType());
-    config.writeEntry(QStringLiteral("ServiceName").prepend(prefix), service().pluginId());
+    //If the view has been delayed, these property can't be got from the part (which will be a PlaceholderPart):
+    //They need to be taken from m_delayedLoadingData.
+    //This can happen when loading a session with several tabs, then saving it again without activating all the
+    //tabs
+    Konq::PlaceholderPart *plPart = placeholderPart();
+    QString mimeType = plPart ? plPart->delayedLoadingData().mimeType : serviceType();
+    QString serviceName = plPart ? plPart->delayedLoadingData().serviceName : service().pluginId();
+    bool locked = plPart ? plPart->delayedLoadingData().lockedLocation : isLockedLocation();
+
+    config.writeEntry(QStringLiteral("ServiceType").prepend(prefix), mimeType);
+    config.writeEntry(QStringLiteral("ServiceName").prepend(prefix), serviceName);
     config.writeEntry(QStringLiteral("PassiveMode").prepend(prefix), isPassiveMode());
     config.writeEntry(QStringLiteral("LinkedView").prepend(prefix), isLinkedView());
     config.writeEntry(QStringLiteral("ToggleView").prepend(prefix), isToggleView());
-    config.writeEntry(QStringLiteral("LockedLocation").prepend(prefix), isLockedLocation());
+    config.writeEntry(QStringLiteral("LockedLocation").prepend(prefix), locked);
 
     if (options & KonqFrameBase::SaveUrls) {
         config.writePathEntry(QStringLiteral("URL").prepend(prefix), url().url());
@@ -1331,6 +1507,62 @@ void KonqView::saveConfig(KConfigGroup &config, const QString &prefix, const Kon
     }
 }
 
+void KonqView::storeDelayedLoadingData(const QString& mimeType, const QString& serviceName, bool openUrl, const QUrl& url, bool lockedLocation, const KConfigGroup& grp, const QString& prefix)
+{
+    Konq::PlaceholderPart *plPart = placeholderPart();
+    if (!plPart) {
+        return;
+    }
+    plPart->setDelayedLoadingData({mimeType, serviceName, openUrl, url, lockedLocation});
+
+    const QString keyHistoryItems = QStringLiteral("NumberOfHistoryItems").prepend(prefix);
+
+    int historySize = grp.readEntry(keyHistoryItems, 0);
+    if (historySize < 1) {
+        //Note: this won't really open the URL because the part will be a PlaceholderPart
+        m_pPart->openUrl(url);
+        return;
+    }
+
+    loadHistoryConfig(grp, prefix);
+    if (!m_lstHistory.isEmpty()) {
+        //Note: this won't really open the URL because the part will be a PlaceholderPart
+        QUrl url = m_lstHistory.at(m_lstHistoryIndex)->url;
+        m_pPart->openUrl(url);
+    }
+}
+
+bool KonqView::isDelayed() const
+{
+    return qobject_cast<Konq::PlaceholderPart*>(m_pPart) != nullptr;
+}
+
+void KonqView::loadDelayed()
+{
+    Konq::PlaceholderPart *plPart = placeholderPart();
+    if (!plPart) {
+        return;
+    }
+
+    Konq::PlaceholderPart::DelayedLoadingData data = plPart->delayedLoadingData();
+    changePart(data.mimeType, data.serviceName, true);
+
+    if (data.openUrl) {
+        if (m_lstHistory.isEmpty()) {
+            QUrl url = data.url;
+            KonqOpenURLRequest req;
+            if (!KonqUrl::hasKonqScheme(url)) {
+                req.typedUrl = url.toDisplayString();
+            }
+            m_pMainWindow->openView(data.mimeType, url, this, req);
+        } else {
+            restoreHistory();
+        }
+    }
+    setLockedLocation(data.lockedLocation);
+    data = {};
+}
+
 void KonqView::loadHistoryConfig(const KConfigGroup &config, const QString &prefix)
 {
     // First, remove any history
@@ -1348,17 +1580,11 @@ void KonqView::loadHistoryConfig(const KConfigGroup &config, const QString &pref
 
     // restore history list
     for (int i = 0; i < historySize; ++i) {
-        HistoryEntry *historyEntry = new HistoryEntry;
 
         // Only current history item saves completely its HistoryEntry
-        KonqFrameBase::Options options;
-        if (i == currentIndex) {
-            options = KonqFrameBase::SaveHistoryItems;
-        } else {
-            options = KonqFrameBase::SaveUrls;
-        }
+        KonqFrameBase::Options options = i == currentIndex ? KonqFrameBase::SaveHistoryItems : KonqFrameBase::SaveUrls;
 
-        historyEntry->loadItem(config, QLatin1String("HistoryItem") + QString::number(i).prepend(prefix), options);
+        HistoryEntry *historyEntry = HistoryEntry::fromDelayedLoadingData(config, QLatin1String("HistoryItem") + QString::number(i).prepend(prefix), options);
 
         appendHistoryEntry(historyEntry);
     }
@@ -1370,7 +1596,6 @@ void KonqView::loadHistoryConfig(const KConfigGroup &config, const QString &pref
 
     // set and load the correct history index
     setHistoryIndex(currentIndex);
-    restoreHistory();
 }
 
 QString KonqView::internalViewMode() const
