@@ -17,6 +17,7 @@
 #include "konqframevisitor.h"
 #include <konq_events.h>
 #include "konqurl.h"
+#include <KX11Extras>
 
 #include <QFileInfo>
 #include <QDBusMessage>
@@ -33,12 +34,12 @@
 #include <kmessagebox.h>
 #include <QMenu>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QStandardPaths>
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QScreen>
 
 //#define DEBUG_VIEWMGR
 
@@ -54,6 +55,14 @@ KonqViewManager::KonqViewManager(KonqMainWindow *mainWindow)
 
     connect(this, SIGNAL(activePartChanged(KParts::Part*)),
             this, SLOT(slotActivePartChanged(KParts::Part*)));
+
+    //When closing a window, tabs will be removed one by one, meaning each one will be activated:
+    //this would trigger their delayed loading, which we don't want. So, when the main window is closed
+    //disconnect the delayedLoadTab slot
+    connect(mainWindow, &KonqMainWindow::closing, this, [this](){
+            disconnect(m_tabContainer, &QTabWidget::currentChanged, this, &KonqViewManager::delayedLoadTab);
+        }
+    );
 }
 
 KonqView *KonqViewManager::createFirstView(const QString &mimeType, const QString &serviceName)
@@ -372,6 +381,9 @@ KonqMainWindow *KonqViewManager::openSavedWindow(const KConfigGroup &configGroup
     mainWindow->applyMainWindowSettings(configGroup);
     mainWindow->activateChild();
 
+    QStringList activities = configGroup.readEntry("Activities", QStringList{});
+    KX11Extras::self()->setOnActivities(mainWindow->winId(), activities);
+
 #ifdef DEBUG_VIEWMGR
     mainWindow->viewManager()->printFullHierarchy();
 #endif
@@ -414,7 +426,7 @@ void KonqViewManager::removeTab(KonqFrameBase *currentFrame, bool emitAboutToRem
     }
 
     const QList<KonqView *> viewList = KonqViewCollector::collect(currentFrame);
-    foreach (KonqView *view, viewList) {
+    for (KonqView *view: viewList) {
         if (view == m_pMainWindow->currentView()) {
             setActivePart(nullptr);
         }
@@ -438,7 +450,7 @@ void KonqViewManager::removeTab(KonqFrameBase *currentFrame, bool emitAboutToRem
 
 void KonqViewManager::reloadAllTabs()
 {
-    foreach (KonqFrameBase *frame, tabContainer()->childFrameList()) {
+    for(KonqFrameBase *frame: tabContainer()->childFrameList()) {
         if (frame && frame->activeChildView()) {
             if (!frame->activeChildView()->locationBarURL().isEmpty()) {
                 frame->activeChildView()->openUrl(frame->activeChildView()->url(), frame->activeChildView()->locationBarURL());
@@ -547,7 +559,7 @@ void KonqViewManager::showTab(int tabIndex)
 void KonqViewManager::updatePixmaps()
 {
     const QList<KonqView *> viewList = KonqViewCollector::collect(tabContainer());
-    foreach (KonqView *view, viewList) {
+    for (KonqView *view: viewList) {
         view->setTabIcon(QUrl::fromUserInput(view->locationBarURL()));
     }
 }
@@ -722,7 +734,7 @@ void KonqViewManager::clear()
     if (!viewList.isEmpty()) {
         //qCDebug(KONQUEROR_LOG) << viewList.count() << "items";
 
-        foreach (KonqView *view, viewList) {
+        for (KonqView *view: viewList) {
             m_pMainWindow->removeChildView(view);
             //qCDebug(KONQUEROR_LOG) << "Deleting" << view;
             delete view;
@@ -821,6 +833,12 @@ KonqViewFactory KonqViewManager::createView(const QString &serviceType,
     return viewFactory;
 }
 
+KonqView* KonqViewManager::setupView(KonqFrameContainerBase* parentContainer, bool passiveMode, bool openAfterCurrentPage, int pos)
+{
+    KonqViewFactory factory;
+    return setupView(parentContainer, factory, {}, {}, {}, {}, passiveMode, openAfterCurrentPage, pos);
+}
+
 KonqView *KonqViewManager::setupView(KonqFrameContainerBase *parentContainer,
                                      KonqViewFactory &viewFactory,
                                      const KPluginMetaData &service,
@@ -835,7 +853,7 @@ KonqView *KonqViewManager::setupView(KonqFrameContainerBase *parentContainer,
 
     QString sType = serviceType;
 
-    if (sType.isEmpty()) { // TODO remove this -- after checking all callers; splitMainContainer seems to need this logic
+    if (sType.isEmpty() && m_pMainWindow->currentView()) { // TODO remove this -- after checking all callers; splitMainContainer seems to need this logic
         sType = m_pMainWindow->currentView()->serviceType();
     }
 
@@ -844,8 +862,13 @@ KonqView *KonqViewManager::setupView(KonqFrameContainerBase *parentContainer,
     newViewFrame->setGeometry(0, 0, m_pMainWindow->width(), m_pMainWindow->height());
 
     //qCDebug(KONQUEROR_LOG) << "Creating KonqView";
-    KonqView *v = new KonqView(viewFactory, newViewFrame,
-                               m_pMainWindow, service, partServiceOffers, appServiceOffers, sType, passiveMode);
+    // KonqView *v = new KonqView(newViewFrame, m_pMainWindow);
+    KonqView *v = nullptr;
+    if (!viewFactory.isNull()) {
+        v = new KonqView(viewFactory, newViewFrame, m_pMainWindow, service, partServiceOffers, appServiceOffers, sType, passiveMode);
+    } else {
+        v = new KonqView(newViewFrame, m_pMainWindow);
+    }
     //qCDebug(KONQUEROR_LOG) << "KonqView created - v=" << v << "v->part()=" << v->part();
 
     connect(v, &KonqView::sigPartChanged, m_pMainWindow, &KonqMainWindow::slotPartChanged);
@@ -1042,7 +1065,7 @@ static QSize readDefaultSize(const KConfigGroup &cfg, QWidget *widget)
     QString heightStr = cfg.readEntry("Height");
     int width = -1;
     int height = -1;
-    const QRect geom = QApplication::desktop()->screenGeometry(widget);
+    const QRect geom = widget->screen()->geometry();
 
     bool ok;
     if (widthStr.endsWith('%')) {
@@ -1099,6 +1122,15 @@ void KonqViewManager::loadRootItem(const KConfigGroup &cfg, KonqFrameContainerBa
 
     m_bLoadingProfile = false;
 
+    //Actually perform delayed loading of the current tab
+    if (m_tabContainer) {
+        KonqFrameBase *frm = m_tabContainer->currentTab();
+        QList<KonqView*> views = KonqViewCollector::collect(frm);
+        for (KonqView *v : views) {
+            v->loadDelayed();
+        }
+    }
+
     m_pMainWindow->enableAllActions(true);
 
     // This flag disables calls to viewCountChanged while creating the views,
@@ -1143,26 +1175,29 @@ void KonqViewManager::loadItem(const KConfigGroup &cfg, KonqFrameContainerBase *
                 }
             }
         }
+
         //qCDebug(KONQUEROR_LOG) << "serviceType" << serviceType << serviceName;
 
-        KPluginMetaData service;
-        QVector<KPluginMetaData> partServiceOffers;
-        KService::List appServiceOffers;
-
-        KonqFactory konqFactory;
-        KonqViewFactory viewFactory = konqFactory.createView(serviceType, serviceName, &service, &partServiceOffers, &appServiceOffers, true /*forceAutoEmbed*/);
-        if (viewFactory.isNull()) {
-            qCWarning(KONQUEROR_LOG) << "Profile Loading Error: View creation failed";
-            return; //ugh..
-        }
-
         bool passiveMode = cfg.readEntry(QStringLiteral("PassiveMode").prepend(prefix), false);
 
         //qCDebug(KONQUEROR_LOG) << "Creating View Stuff; parent=" << parent;
         if (parent == m_pMainWindow) {
             parent = tabContainer();
         }
-        KonqView *childView = setupView(parent, viewFactory, service, partServiceOffers, appServiceOffers, serviceType, passiveMode, openAfterCurrentPage, pos);
+
+        QUrl url;
+        if (openUrl) {
+            const QString urlKey = QStringLiteral("URL").prepend(prefix);
+            if (cfg.hasKey(urlKey)) {
+                url = QUrl(cfg.readPathEntry(urlKey, KonqUrl::string(KonqUrl::Type::Blank)));
+            } else {
+                url = defaultURL;
+            }
+        }
+
+        KonqView *childView = setupView(parent, passiveMode, openAfterCurrentPage, pos);
+        bool lockedLocation = cfg.readEntry(QStringLiteral("LockedLocation").prepend(prefix), false);
+        childView->storeDelayedLoadingData(serviceType, serviceName, openUrl, url, lockedLocation, cfg, prefix);
 
         if (!childView->isFollowActive()) {
             childView->setLinkedView(cfg.readEntry(QStringLiteral("LinkedView").prepend(prefix), false));
@@ -1177,39 +1212,6 @@ void KonqViewManager::loadItem(const KConfigGroup &cfg, KonqFrameContainerBase *
             // First tab, make it the active one
             parent->setActiveChild(childView->frame());
         }
-
-        if (openUrl) {
-            const QString keyHistoryItems = QStringLiteral("NumberOfHistoryItems").prepend(prefix);
-            if (cfg.hasKey(keyHistoryItems)) {
-                childView->loadHistoryConfig(cfg, prefix);
-                m_pMainWindow->updateHistoryActions();
-            } else {
-                // determine URL
-                const QString urlKey = QStringLiteral("URL").prepend(prefix);
-                QUrl url;
-                if (cfg.hasKey(urlKey)) {
-                    url = QUrl(cfg.readPathEntry(urlKey, KonqUrl::string(KonqUrl::Type::Blank)));
-                } else if (urlKey == QLatin1String("empty_URL")) { // old stuff, not in use anymore
-                    url = KonqUrl::url(KonqUrl::Type::Blank);
-                } else {
-                    url = defaultURL;
-                }
-
-                if (!url.isEmpty()) {
-                    //qCDebug(KONQUEROR_LOG) << "calling openUrl" << url;
-                    //childView->openUrl( url, url.toDisplayString() );
-                    // We need view-follows-view (for the dirtree, for instance)
-                    KonqOpenURLRequest req;
-                    if (!KonqUrl::hasKonqScheme(url)) {
-                        req.typedUrl = url.toDisplayString();
-                    }
-                    m_pMainWindow->openView(serviceType, url, childView, req);
-                }
-                //else qCDebug(KONQUEROR_LOG) << "url is empty";
-            }
-        }
-        // Do this after opening the URL, so that it's actually possible to open it :)
-        childView->setLockedLocation(cfg.readEntry(QStringLiteral("LockedLocation").prepend(prefix), false));
     } else if (name.startsWith(QLatin1String("Container"))) {
         //qCDebug(KONQUEROR_LOG) << "Item is Container";
 
@@ -1314,7 +1316,7 @@ void KonqViewManager::printSizeInfo(KonqFrameBase *frame,
     if (parent->frameType() == KonqFrameBase::Container) {
         const QList<int> sizes = static_cast<KonqFrameContainer *>(parent)->sizes();
         printf("Parent sizes %s :", msg);
-        foreach (int i, sizes) {
+        for (int i: sizes) {
             printf(" %d", i);
         }
         printf("\n");
@@ -1433,6 +1435,7 @@ void KonqViewManager::createTabContainer(QWidget *parent, KonqFrameContainerBase
     m_tabContainer = new KonqFrameTabs(parent, parentContainer, this);
     // Delay the opening of the URL for #106641
     bool ok = connect(m_tabContainer, SIGNAL(openUrl(KonqView*,QUrl)), m_pMainWindow, SLOT(openUrl(KonqView*,QUrl)), Qt::QueuedConnection);
+    connect(m_tabContainer, &QTabWidget::currentChanged, this, &KonqViewManager::delayedLoadTab);
     Q_ASSERT(ok);
     Q_UNUSED(ok);
     applyConfiguration();
@@ -1460,4 +1463,23 @@ KonqMainWindow *KonqViewManager::duplicateWindow()
     return mainWindow;
 }
 
+void KonqViewManager::reparseConfiguration()
+{
+    if (m_tabContainer) {
+        m_tabContainer->reparseConfiguration();
+    }
+}
 
+void KonqViewManager::delayedLoadTab(int idx)
+{
+    if (!m_tabContainer || m_bLoadingProfile) {
+        return;
+    }
+    KonqFrameBase *frm = m_tabContainer->tabAt(idx);
+    QList<KonqView*> views = KonqViewCollector::collect(frm);
+    for (KonqView *v : views) {
+        if (v && v->isDelayed()) {
+            v->loadDelayed();
+        }
+    }
+}
